==> tecfy_core_package-1.1.8.tar.gz: lib/views/components/general/dropdown.component.dart <==
part of tecfy_core_client_package;

class DropdownComponenet extends StatefulWidget {
  final String? label;
  final String? description;
  final bool isRequired;
  final bool readOnly;
  final String? initalValue;
  final List<Map<String, dynamic>>? options;
  final String idProperty;
  final String displayProperty;
  final void Function(String?)? onChanged;
  DropdownComponenet({
    this.label,
    this.description,
    this.options,
    this.initalValue,
    this.onChanged,
    this.isRequired = false,
    this.readOnly = false,
    this.idProperty = 'id',
    this.displayProperty = 'name',
  });
  @override
  _DropdownComponenetState createState() => _DropdownComponenetState();
}

class _DropdownComponenetState extends AppState<DropdownComponenet> {
  List<Map<String, dynamic>>? _data;
  String? _value;
  @override
  void initState() {
    _value = widget.initalValue;
    _data = widget.options;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _data == null
        ? Text('${trans('Loading')}..')
        : DropdownButtonFormField<String>(
            decoration: InputDecoration(
                helperText: widget.description,
                labelText: widget.label == null
                    ? null
                    : '${trans(widget.label)}${widget.isRequired ? '*' : ''}'),
            value: (_data?.any((e) => e[widget.idProperty] == _value) ?? false)
                ? _value
                : null,
            onChanged: widget.readOnly
                ? null
                : (v) {
                    _value = v;
                    widget.onChanged?.call(v);
                    setState(() {});
                  },
            items: (_data
                    ?.map<DropdownMenuItem<String>>((item) => DropdownMenuItem(
                          child: Text(
                            item[widget.displayProperty] ??
                                item['display'] ??
                                item['name'] ??
                                item['nameAr'] ??
                                item['nameEn'] ??
                                'N/A',
                            style: TextStyle(color: Colors.black),
                          ),
                          value: item[widget.idProperty],
                        ))
                    .toList() ??
                [])
              ..add(_value == null
                  ? DropdownMenuItem(child: Container())
                  : DropdownMenuItem(
                      child: Text('غير محدد',
                          style: TextStyle(color: Colors.black38)),
                      value: null,
                    )),
          );
  }
}

==> tecfy_core_package-1.1.25.tar.gz: lib/views/components/general/dropdown.component.dart <==
part of tecfy_core_client_package;

class DropdownComponenet extends StatefulWidget {
  final String? label;
  final String? description;
  final bool isRequired;
  final bool readOnly;
  final String? initalValue;
  final List<Map<String, dynamic>>? options;
  final String idProperty;
  final String displayProperty;
  final void Function(String?)? onChanged;
  DropdownComponenet({
    this.label,
    this.description,
    this.options,
    this.initalValue,
    this.onChanged,
    this.isRequired = false,
    this.readOnly = false,
    this.idProperty = 'id',
    this.displayProperty = 'name',
  });
  @override
  _DropdownComponenetState createState() => _DropdownComponenetState();
}

class _DropdownComponenetState extends AppState<DropdownComponenet> {
  List<Map<String, dynamic>>? _data;
  String? _value;
  @override
  void initState() {
    _value = widget.initalValue;
    _data = widget.options;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _data == null
        ? TecfyText('${trans('Loading')}..')
        : DropdownButtonFormField<String>(
            decoration: InputDecoration(
                helperText: widget.description,
                labelText: widget.label == null
                    ? null
                    : '${trans(widget.label)}${widget.isRequired ? '*' : ''}'),
            value: (_data?.any((e) => e[widget.idProperty] == _value) ?? false)
                ? _value
                : null,
            onChanged: widget.readOnly
                ? null
                : (v) {
                    _value = v;
                    widget.onChanged?.call(v);
                    setState(() {});
                  },
            items: (_data
                    ?.map<DropdownMenuItem<String>>((item) => DropdownMenuItem(
                          child: TecfyText(
                            item[widget.displayProperty] ??
                                item['display'] ??
                                item['name'] ??
                                item['nameAr'] ??
                                item['nameEn'] ??
                                'N/A',
                            style: TextStyle(color: Colors.black),
                          ),
                          value: item[widget.idProperty],
                        ))
                    .toList() ??
                [])
              ..add(_value == null
                  ? DropdownMenuItem(child: Container())
                  : DropdownMenuItem(
                      child: TecfyText('غير محدد',
                          style: TextStyle(color: Colors.black38)),
                      value: null,
                    )),
          );
  }
}
